# Introduction

Python wrapper around the
[Fortran ciaaw library](https://milanskocic.github.io/ciaaw/index.html).
The Fortran library does not need to be installed, the python wrapper embeds all needed fortran dependencies
for Windows and MacOS.
On linux, you might have to install `libgfortran` if it is not distributed by default with your linux distribution. 



# Installation

```
pip install pyciaaw
```



# License

MIT
